A Python library for logging with fixed-formatted data. Designed for logging in machine-learning projects.

## API

TK.

## Install

TK.

## Todo

- Build out base `Parse`.
- Support tabular data; `TableLogger`?
